@@ -1,12 +1,11 @@
 from contracts_lib_py.conditions.condition_base import ConditionBase
-from contracts_lib_py.event_filter import EventFilter
 
 
 class TransferNFTCondition(ConditionBase):
     """Class representing the TransferNFTCondition contract."""
     CONTRACT_NAME = 'TransferNFTCondition'
 
-    def fulfill(self, agreement_id, did, receiver_address, nft_amount, lock_cond_id, account):
+    def fulfill(self, agreement_id, did, receiver_address, nft_amount, lock_cond_id, nft_contract_address, transfer, account):
         """
         Fulfill the NFT Holder condition.
 
@@ -16,6 +15,8 @@ class TransferNFTCondition(ConditionBase):
         :param receiver_address: is the address of the user to receive the NFT, str
         :param nft_amount: number of NFTs to hold, str
         :param lock_cond_id: Lock Condition Identifier, str
+        :param nft_contract_address: The address of the NFT Contract to use, str
+        :param transfer if yes it does a transfer if false it mints the NFT, bool
         :param account: Account instance
         :return: true if the condition was successfully fulfilled, bool
         """
@@ -25,12 +26,15 @@ class TransferNFTCondition(ConditionBase):
             receiver_address,
             nft_amount,
             lock_cond_id,
+            nft_contract_address,
+            transfer,
             transact={'from': account.address,
                       'passphrase': account.password,
                       'keyfile': account.key_file}
         )
 
-    def fulfill_for_delegate(self, agreement_id, did, nft_holder_address, receiver_address, nft_amount, lock_cond_id, account):
+    def fulfill_for_delegate(self, agreement_id, did, nft_holder_address, receiver_address, nft_amount, lock_cond_id,
+                             transfer, account):
         """
         Fulfill the NFT Holder condition.
 
@@ -41,6 +45,7 @@ class TransferNFTCondition(ConditionBase):
         :param receiver_address: is the address of the user to receive the NFT, str
         :param nft_amount: number of NFTs to hold, str
         :param lock_cond_id: Lock Condition Identifier, str
+        :param transfer if yes it does a transfer if false it mints the NFT, bool
         :param account: Account instance
         :return: true if the condition was successfully fulfilled, bool
         """
@@ -51,6 +56,7 @@ class TransferNFTCondition(ConditionBase):
             receiver_address,
             nft_amount,
             lock_cond_id,
+            transfer,
             method='fulfillForDelegate',
             transact={'from': account.address,
                       'passphrase': account.password,
@@ -58,7 +64,7 @@ class TransferNFTCondition(ConditionBase):
                       'gas': 1000000}
         )
 
-    def hash_values(self, did, nft_holder, receiver_address, nft_amount, lock_cond_id):
+    def hash_values(self, did, nft_holder, receiver_address, nft_amount, lock_cond_id, nft_contract_address, transfer):
         """
         Hast the values of the document_id with the grantee address.
 
@@ -68,8 +74,17 @@ class TransferNFTCondition(ConditionBase):
         :param receiver_address: is the address of the user to receive the NFT, str
         :param nft_amount: number of NFTs, str
         :param lock_cond_id: Lock Condition Identifier, str
+        :param nft_contract_address: The address of the NFT Contract to use
+        :param transfer if yes it does a transfer if false it mints the NFT, bool
         :return: hex str
         """
-        return self._hash_values(did, nft_holder, receiver_address, nft_amount, lock_cond_id)
+        return self._hash_values(did, nft_holder, receiver_address, nft_amount, lock_cond_id, nft_contract_address, transfer)
 
+    def get_nft_default_address(self):
+        """
+        Returns the default NFT Contract used in the Transfer Condition
+
+        :return: nft contract address
+        """
+        return self._get_nft_default_address()
 
